// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `RDFa Vocabulary for Term and Prefix Assignment, and for Processor Graph Reporting` vocabulary
//!
//! This module requires `ns-rdfa` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|RDFa Vocabulary for Term and Prefix Assignment, and for Processor Graph Reporting|
//! |**Prefix**|rdfa|
//! |**Namespace base IRI**|<http://www.w3.org/ns/rdfa#>|
//! |**Description**|This document describes the RDFa Vocabulary for Term and Prefix Assignment. The Vocabulary is used to modify RDFa 1.1 processing behavior.|
//! |**Is defined by**|<http://www.w3.org/ns/rdfa#>|
//!

use crate::namespace;

namespace!(
    "http://www.w3.org/ns/rdfa#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `DocumentError`: 
    DocumentError, "DocumentError",
    /// `Error`: 
    Error, "Error",
    /// `Info`: 
    Info, "Info",
    /// `PGClass`: 
    PGClass, "PGClass",
    /// `Pattern`: 
    Pattern, "Pattern",
    /// `PrefixMapping`: 
    PrefixMapping, "PrefixMapping",
    /// `PrefixOrTermMapping`: 
    PrefixOrTermMapping, "PrefixOrTermMapping",
    /// `PrefixRedefinition`: 
    PrefixRedefinition, "PrefixRedefinition",
    /// `TermMapping`: 
    TermMapping, "TermMapping",
    /// `UnresolvedCURIE`: 
    UnresolvedCURIE, "UnresolvedCURIE",
    /// `UnresolvedTerm`: 
    UnresolvedTerm, "UnresolvedTerm",
    /// `VocabReferenceError`: 
    VocabReferenceError, "VocabReferenceError",
    /// `Warning`: 
    Warning, "Warning",
    /// `context`: 
    context, "context",
    /// `copy`: 
    copy, "copy",
    /// `prefix`: 
    prefix, "prefix",
    /// `term`: 
    term, "term",
    /// `uri`: 
    uri, "uri",
    /// `usesVocabulary`: 
    usesVocabulary, "usesVocabulary",
    /// `vocabulary`: 
    vocabulary, "vocabulary"
);
